@@ -49,8 +49,10 @@ extern "C" {
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <fixx11h.h>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QtX11Extras/QX11Info>
 #endif
+#endif
 
 // local
 #include "gwenview_lib_debug.h"
@@ -179,7 +181,7 @@ Profile::Ptr Profile::loadFromExiv2Image(const Exiv2::Image* image)
     QByteArray data;
     data.resize(size);
     it->copy(reinterpret_cast<Exiv2::byte*>(data.data()), Exiv2::invalidByteOrder);
-    hProfile = cmsOpenProfileFromMem(data, size);
+    hProfile = cmsOpenProfileFromMem(data.constData(), size);
 
     if (hProfile) {
         ptr = new Profile(hProfile);
@@ -193,7 +195,7 @@ Profile::Ptr Profile::loadFromICC(const QByteArray &data)
     int size = data.size();
 
     if (size > 0) {
-        cmsHPROFILE hProfile = cmsOpenProfileFromMem(data, size);
+        cmsHPROFILE hProfile = cmsOpenProfileFromMem(data.constData(), size);
 
         if (hProfile) {
             ptr = new Profile(hProfile);
