@@ -55,12 +55,12 @@ static const int INITIAL_HIDE_TIMEOUT = 2000;
 static const int EXTRA_BAR_HEIGHT = 20;
 
 struct FullScreenBarPrivate {
-    FullScreenBar *q;
-    QTimeLine *mTimeLine;
-    QTimer *mAutoHideCursorTimer;
+    FullScreenBar *q = nullptr;
+    QTimeLine *mTimeLine = nullptr;
+    QTimer *mAutoHideCursorTimer = nullptr;
     bool mAutoHidingEnabled;
     bool mEdgeTriggerEnabled;
-    QTimer *mInitialHideTimer;
+    QTimer *mInitialHideTimer = nullptr;
 
     void startTimeLine()
     {
@@ -73,7 +73,7 @@ struct FullScreenBarPrivate {
     {
         QBitmap empty(32, 32);
         empty.clear();
-        QCursor blankCursor(empty, empty);
+        const QCursor blankCursor(empty, empty);
         QApplication::setOverrideCursor(blankCursor);
     }
 
@@ -236,7 +236,7 @@ bool FullScreenBar::eventFilter(QObject *object, QEvent *event)
                 slideOut();
             }
         } else {
-            auto *mouseEvent = static_cast<QMouseEvent *>(event);
+            auto mouseEvent = static_cast<QMouseEvent *>(event);
             if (d->mEdgeTriggerEnabled && mouseEvent->buttons() == 0 && d->slideInTriggerRect().contains(QCursor::pos())) {
                 slideIn();
             }
@@ -262,10 +262,10 @@ bool FullScreenBar::eventFilter(QObject *object, QEvent *event)
     // parenthesis construct should be removed. Use KLocale's method to do this.
     // """
     if (event->type() == QEvent::Show || event->type() == QEvent::Paint) {
-        auto *button = qobject_cast<QToolButton *>(object);
+        auto button = qobject_cast<QToolButton *>(object);
         if (button && !button->actions().isEmpty()) {
             QAction *action = button->actions().constFirst();
-            QString toolTip = KLocalizedString::removeAcceleratorMarker(action->toolTip());
+            const QString toolTip = KLocalizedString::removeAcceleratorMarker(action->toolTip());
             // Filtering message requested by translators (scripting).
             button->setToolTip(i18nc("@info:tooltip of custom toolbar button", "%1", toolTip));
         }
